The first set of columns in the discharge level data (typically through column R) contain the protected health information (PHI)
associated with the discharges, such as medical record identifiers, admission/discharge/readmission dates, index diagnoses, etc. which
can be used to identify the specific patients contributing (and not contributing) to the CMS penalty calculation for the cohort.
The risk factors contain the discharge-level clinical information used for individual risk adjustment by
CMS to estimate individual level readmission rates. These can be useful to explore to understand risk factor
distributions and prevalence, especially in combination with hsr_coefficients() which indicates the
risk factors most heavily-weighted in the readmission risk calculation.
The HSR contains discharges that were not necessarily included/eligible to be counted in the
Hospital Readmissions Reduction Program (HRRP).
Setting eligible_only = TRUE will filter the returned result to only those that are eligible, and thus should match the denominator
displayed in hsr_cohort_summary().