Learn R Programming

readmit (version 0.0.1)

hsr_dual_stays: Extract dually-eligible discharges from a Hospital-Specific Report (HSR)

Description

Parses the discharge-level records from the HSR of patients who were dually-eligible for Medicare and Medicaid benefits (see details).

Note: CMS changed the format of Hospital-Specific Reports (HSRs) for FY2026 (see here). The current HSR functions support formats through FY2025.

Usage

hsr_dual_stays(file)

Value

A tibble::tibble()

Arguments

file

File path to a report

Details

In the Hospital Readmissions Reduction Program (HRRP), hospitals' readmission rates are compared against a peer group of "like" hospitals, which determines whether or not they will get penalized financially.

The peer group allocation done by CMS is determined by creating hospital groupings based on the share of Medicare beneficiaries who were also eligible for Medicaid benefits, a marker of socioeconomic status in the hospital population. hsr_dual_stays() extracts the list of discharges accounting for the numerator of this ratio.

Examples

Run this code
# Access a report
my_report <- hsr_mock_reports("FY2025_HRRP_MockHSR.xlsx")

# Extract dually-eligible stays as a dataset
hsr_dual_stays(my_report)

Run the code above in your browser using DataLab